'''This module provides the list of known configurations that can be used
throughout the application.

Automatically generated using the following:
python -c "import adhawkapi.trackermodel; adhawkapi.trackermodel.main()" -o adhawkapi

'''

# pylint: disable=too-many-lines
MODEL = {
    'tracker0': {
        'title': 'Right eye',
        'children': {
            'specs': {
                'title': 'Specs',
                'children': {
                    'xmin': {
                        'title': 'X min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 0,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'xmax': {
                        'title': 'X min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 1023,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'ymin': {
                        'title': 'Y min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 0,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'ymax': {
                        'title': 'Y max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 1023,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'max_laser_current': {
                        'title': 'Max laser current',
                        'type': 'int',
                        'min': 0.0,
                        'max': 45.5,
                        'step': 0.01,
                        'factoryval': 10.5,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                },
            },
            'lasercurrentpct': {
                'title': 'Brightness (%)',
                'type': 'float',
                'min': 0.0,
                'max': 100.0,
                'step': 1.0,
                'factoryval': 50.0,
                'related': ['lasercurrent'],
            },
            'lasercurrent': {
                'title': 'Laser current (mA)',
                'type': 'float',
                'min': 0.0,
                'max': 45.5,
                'step': 0.01,
                'factoryval': 5.0,
                'related': ['lasercurrentpct'],
            },
            'modulationfrequency': {
                'title': 'Modulation frequency (MHz)',
                'type': 'float',
                'min': 1,
                'max': 10,
                'step': 1,
                'factoryval': 2,
            },
            'modulationdutycycle': {
                'title': 'Modulation duty cycle (%)',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 50,
            },
            'frequency': {
                'title': 'X Frequency',
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 3500,
            },
            'yfrequency': {
                'title': 'Y Frequency',
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 2500,
            },
            'xresonancefrequency': {
                'title': 'X Resonance Frequency',
                'writable': ['STORAGE', 'HARDWARE', 'REMOTE_SERVER', 'ADMIN'],
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 3500,
            },
            'yresonancefrequency': {
                'title': 'Y Resonance Frequency',
                'writable': ['STORAGE', 'HARDWARE', 'REMOTE_SERVER', 'ADMIN'],
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 2500,
            },
            'xphase': {
                'title': 'X Phase',
                'type': 'float',
                'min': 0,
                'max': 360,
                'step': 0.001,
                'factoryval': 0,
            },
            'yphase': {
                'title': 'Y Phase',
                'type': 'float',
                'min': 0,
                'max': 360,
                'step': 0.001,
                'factoryval': 0,
            },
            'glintpwfilterthreshold': {
                'title': 'Glint pulse width threshold',
                'type': 'range',
                'subtype': 'int',
                'children': {
                    'min': {'min': 0, 'factoryval': 0},
                    'max': {'max': 8190, 'factoryval': 4095},
                },
            },
            'pupilpwfilterthreshold': {
                'title': 'Pupil pulse width threshold',
                'type': 'range',
                'subtype': 'int',
                'children': {
                    'min': {'min': 0, 'factoryval': 0},
                    'max': {'max': 8190, 'factoryval': 4095},
                },
            },
            'pd0': {
                'title': 'Glint detector 1',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd1': {
                'title': 'Glint detector 2',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd2': {
                'title': 'Glint detector 3',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd3': {
                'title': 'Glint detector 4',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd4': {
                'title': 'Glint detector 5',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd5': {
                'title': 'Glint detector 6',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pupilpd0': {
                'title': 'Pupil detector 1',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pupilpd1': {
                'title': 'Pupil detector 2',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'detector0': {
                'title': 'Detector 1',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'detector1': {
                'title': 'Detector 2',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'detector2': {
                'title': 'Detector 3',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'xmean': {
                'title': 'X mean',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 400,
                'related': ['xmean_pct'],
            },
            'xmean_pct': {
                'title': 'X mean',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 40,
                'related': ['xmean'],
            },
            'ymean': {
                'title': 'Y mean',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 512,
                'related': ['ymean_pct'],
            },
            'ymean_pct': {
                'title': 'Y mean',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 50,
                'related': ['ymean'],
            },
            'width': {
                'title': 'Width',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 300,
                'related': ['width_pct'],
            },
            'width_pct': {
                'title': 'Width',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 30,
                'related': ['width'],
            },
            'height': {
                'title': 'Height',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 200,
                'related': ['height_pct'],
            },
            'height_pct': {
                'title': 'Height',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 20,
                'related': ['height'],
            },
            'xdeadtime': {
                'title': 'X Dead Time',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 0,
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
            },
            'ydeadtime': {
                'title': 'Y Dead Time',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 0,
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
            },
            'deadtimemode': {
                'title': 'Dead Time Mode',
                'type': 'list',
                'values': {
                    'No Dead Time': 0,
                    'Constant Time Half Cycle Max': 1,
                    'Constant Time Full Cycle Max': 2,
                },
                'factoryval': 0,
                'related': ['deadtime_enable'],
            },
            'autotune': {
                'title': 'Auto-tune',
                'type': 'action',
                'disable_on_start': False,
                'expanded': False,
                'children': {
                    'xrange': {
                        'title': 'X sweep range',
                        'type': 'range',
                        'subtype': 'int',
                        'children': {
                            'min': {'min': 0, 'factoryval': 0},
                            'max': {'max': 1023, 'factoryval': 1023},
                            'step': {'factoryval': 5},
                        },
                    },
                    'yrange': {
                        'title': 'Y sweep range',
                        'type': 'range',
                        'subtype': 'int',
                        'children': {
                            'min': {'min': 0, 'factoryval': 0},
                            'max': {'max': 1023, 'factoryval': 1023},
                            'step': {'factoryval': 5},
                        },
                    },
                    'large_megalisa_subwindow_x_min': {
                        'title': 'Large Megalisa Subwindow X Min',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'large_megalisa_subwindow_x_max': {
                        'title': 'Large Megalisa Subwindow X Max',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'large_megalisa_subwindow_y_min': {
                        'title': 'Large Megalisa Subwindow Y Min',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'large_megalisa_subwindow_y_max': {
                        'title': 'Large Megalisa Subwindow Y Max',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'nominal_subwindow_x_min': {
                        'title': 'Large Megalisa Subwindow X Min',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'nominal_subwindow_x_max': {
                        'title': 'Large Megalisa Subwindow X Max',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'nominal_subwindow_y_min': {
                        'title': 'Large Megalisa Subwindow Y Min',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'nominal_subwindow_y_max': {
                        'title': 'Large Megalisa Subwindow Y Max',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'enablediag': {
                        'title': 'Enable diagnostics',
                        'type': 'bool',
                        'factoryval': True,
                    },
                    'algorithm': {
                        'title': 'Auto-tune algorithm',
                        'type': 'list',
                        'values': {
                            'Analog': 0,
                            'Digital box sweep': 1,
                            'Digital line sweep': 2,
                            'Digital line sweep v2': 3,
                            'Box sizing': 4,
                        },
                        'factoryval': 3,
                    },
                    'algorithm_step1': {
                        'title': 'Centering Algorithm',
                        'type': 'list',
                        'values': {'No-Op': 0, 'Linesweep V2': 1, 'Physmodel': 3},
                        'factoryval': 3,
                    },
                    'algorithm_step2': {
                        'title': 'Box Sizing Algorithm',
                        'type': 'list',
                        'values': {'No-Op': 0, 'Modulecal Glint-based': 2},
                        'factoryval': 0,
                    },
                    'large_megalisa_xphase': {
                        'title': 'Large Megalisa X Phase',
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'large_megalisa_yphase': {
                        'title': 'Large Megalisa Y Phase',
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'nominal_x_min': {
                        'title': 'Nominal Autotune X Min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 0,
                    },
                    'nominal_x_max': {
                        'title': 'Nominal Autotune X Max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 1023,
                    },
                    'nominal_y_min': {
                        'title': 'Nominal Autotune Y Min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 0,
                    },
                    'nominal_y_max': {
                        'title': 'Nominal Autotune Y Max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 1023,
                    },
                },
            },
            'metrics': {
                'title': 'Per Tracker Metrics',
                'children': {
                    'lifetime_running_counter': {
                        'title': 'Running Lifetime Counter',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'uint',
                        'min': 0,
                        'step': 0.001,
                        'factoryval': 0,
                    }
                },
            },
            'operational': {
                'title': 'Operational',
                'children': {
                    'xphase': {
                        'title': 'X Phase',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'yphase': {
                        'title': 'Y Phase',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                },
            },
            'eye_model': {
                'title': 'Model-based Eye Information',
                'children': {
                    'pos_x': {
                        'title': 'X Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                    'pos_y': {
                        'title': 'Y Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                    'pos_z': {
                        'title': 'Z Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                },
            },
            'deadtime_enable': {
                'title': 'Enable Dead Time',
                'type': 'bool',
                'factoryval': False,
                'related': ['deadtimemode'],
            },
            'component_offset_x': {
                'title': 'Component Offset X (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'component_offset_y': {
                'title': 'Component Offset Y (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'component_offset_z': {
                'title': 'Component Offset Z (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'subwindowing_enable': {
                'title': 'Sub Windowing Enable',
                'type': 'bool',
                'factoryval': False,
            },
            'subwindowing_x_min': {
                'title': 'Sub Windowing X Min',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_y_min': {
                'title': 'Sub Windowing Y Min',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_x_max': {
                'title': 'Sub Windowing X Max',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_y_max': {
                'title': 'Sub Windowing Y Max',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
        },
    },
    'tracker1': {
        'title': 'Left eye',
        'children': {
            'specs': {
                'title': 'Specs',
                'children': {
                    'xmin': {
                        'title': 'X min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 0,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'xmax': {
                        'title': 'X min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 1023,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'ymin': {
                        'title': 'Y min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 0,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'ymax': {
                        'title': 'Y max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 5,
                        'factoryval': 1023,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                    'max_laser_current': {
                        'title': 'Max laser current',
                        'type': 'int',
                        'min': 0.0,
                        'max': 45.5,
                        'step': 0.01,
                        'factoryval': 10.5,
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                    },
                },
            },
            'lasercurrentpct': {
                'title': 'Brightness (%)',
                'type': 'float',
                'min': 0.0,
                'max': 100.0,
                'step': 1.0,
                'factoryval': 50.0,
                'related': ['lasercurrent'],
            },
            'lasercurrent': {
                'title': 'Laser current (mA)',
                'type': 'float',
                'min': 0.0,
                'max': 45.5,
                'step': 0.01,
                'factoryval': 5.0,
                'related': ['lasercurrentpct'],
            },
            'modulationfrequency': {
                'title': 'Modulation frequency (MHz)',
                'type': 'float',
                'min': 1,
                'max': 10,
                'step': 1,
                'factoryval': 2,
            },
            'modulationdutycycle': {
                'title': 'Modulation duty cycle (%)',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 50,
            },
            'frequency': {
                'title': 'X Frequency',
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 3500,
            },
            'yfrequency': {
                'title': 'Y Frequency',
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 2500,
            },
            'xresonancefrequency': {
                'title': 'X Resonance Frequency',
                'writable': ['STORAGE', 'HARDWARE', 'REMOTE_SERVER', 'ADMIN'],
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 3500,
            },
            'yresonancefrequency': {
                'title': 'Y Resonance Frequency',
                'writable': ['STORAGE', 'HARDWARE', 'REMOTE_SERVER', 'ADMIN'],
                'type': 'int',
                'min': 1000,
                'max': 10000,
                'step': 5,
                'factoryval': 2500,
            },
            'xphase': {
                'title': 'X Phase',
                'type': 'float',
                'min': 0,
                'max': 360,
                'step': 0.001,
                'factoryval': 0,
            },
            'yphase': {
                'title': 'Y Phase',
                'type': 'float',
                'min': 0,
                'max': 360,
                'step': 0.001,
                'factoryval': 0,
            },
            'glintpwfilterthreshold': {
                'title': 'Glint pulse width threshold',
                'type': 'range',
                'subtype': 'int',
                'children': {
                    'min': {'min': 0, 'factoryval': 0},
                    'max': {'max': 8190, 'factoryval': 4095},
                },
            },
            'pupilpwfilterthreshold': {
                'title': 'Pupil pulse width threshold',
                'type': 'range',
                'subtype': 'int',
                'children': {
                    'min': {'min': 0, 'factoryval': 0},
                    'max': {'max': 8190, 'factoryval': 4095},
                },
            },
            'pd0': {
                'title': 'Glint detector 1',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd1': {
                'title': 'Glint detector 2',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd2': {
                'title': 'Glint detector 3',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd3': {
                'title': 'Glint detector 4',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd4': {
                'title': 'Glint detector 5',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pd5': {
                'title': 'Glint detector 6',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pupilpd0': {
                'title': 'Pupil detector 1',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'pupilpd1': {
                'title': 'Pupil detector 2',
                'children': {
                    'enable': {'title': 'Enable', 'type': 'bool', 'factoryval': True},
                    'gain': {
                        'title': 'Gain',
                        'type': 'int',
                        'min': 0,
                        'max': 25,
                        'factoryval': 20,
                    },
                    'gainboost': {
                        'title': 'Gain boost',
                        'type': 'bool',
                        'factoryval': False,
                    },
                },
            },
            'detector0': {
                'title': 'Detector 1',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'detector1': {
                'title': 'Detector 2',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'detector2': {
                'title': 'Detector 3',
                'children': {
                    'detectortype': {
                        'title': 'Detector type',
                        'type': 'list',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'factoryval': 0,
                        'values': {'Unused': 0, 'Glint': 0, 'Pupil': 1, 'Shared': 2},
                    },
                    'glintenable': {
                        'title': 'Enable Glint Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'pupilenable': {
                        'title': 'Enable Pupil Detector',
                        'type': 'bool',
                        'factoryval': False,
                    },
                    'commongain': {
                        'title': 'Common Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 3,
                        'factoryval': 1,
                    },
                    'glintgain': {
                        'title': 'Glint Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 6,
                        'factoryval': 1,
                    },
                    'pupilgain': {
                        'title': 'Pupil Gain',
                        'type': 'int',
                        'min': 1,
                        'max': 4,
                        'factoryval': 1,
                    },
                },
            },
            'xmean': {
                'title': 'X mean',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 400,
                'related': ['xmean_pct'],
            },
            'xmean_pct': {
                'title': 'X mean',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 40,
                'related': ['xmean'],
            },
            'ymean': {
                'title': 'Y mean',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 512,
                'related': ['ymean_pct'],
            },
            'ymean_pct': {
                'title': 'Y mean',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 50,
                'related': ['ymean'],
            },
            'width': {
                'title': 'Width',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 300,
                'related': ['width_pct'],
            },
            'width_pct': {
                'title': 'Width',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 30,
                'related': ['width'],
            },
            'height': {
                'title': 'Height',
                'type': 'int',
                'min': 0,
                'max': 1023,
                'step': 5,
                'factoryval': 200,
                'related': ['height_pct'],
            },
            'height_pct': {
                'title': 'Height',
                'type': 'int',
                'min': 0,
                'max': 100,
                'step': 1,
                'factoryval': 20,
                'related': ['height'],
            },
            'xdeadtime': {
                'title': 'X Dead Time',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 0,
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
            },
            'ydeadtime': {
                'title': 'Y Dead Time',
                'type': 'int',
                'min': 0,
                'max': 100,
                'factoryval': 0,
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
            },
            'deadtimemode': {
                'title': 'Dead Time Mode',
                'type': 'list',
                'values': {
                    'No Dead Time': 0,
                    'Constant Time Half Cycle Max': 1,
                    'Constant Time Full Cycle Max': 2,
                },
                'factoryval': 0,
                'related': ['deadtime_enable'],
            },
            'autotune': {
                'title': 'Auto-tune',
                'type': 'action',
                'disable_on_start': False,
                'expanded': False,
                'children': {
                    'xrange': {
                        'title': 'X sweep range',
                        'type': 'range',
                        'subtype': 'int',
                        'children': {
                            'min': {'min': 0, 'factoryval': 0},
                            'max': {'max': 1023, 'factoryval': 1023},
                            'step': {'factoryval': 5},
                        },
                    },
                    'yrange': {
                        'title': 'Y sweep range',
                        'type': 'range',
                        'subtype': 'int',
                        'children': {
                            'min': {'min': 0, 'factoryval': 0},
                            'max': {'max': 1023, 'factoryval': 1023},
                            'step': {'factoryval': 5},
                        },
                    },
                    'large_megalisa_subwindow_x_min': {
                        'title': 'Large Megalisa Subwindow X Min',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'large_megalisa_subwindow_x_max': {
                        'title': 'Large Megalisa Subwindow X Max',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'large_megalisa_subwindow_y_min': {
                        'title': 'Large Megalisa Subwindow Y Min',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'large_megalisa_subwindow_y_max': {
                        'title': 'Large Megalisa Subwindow Y Max',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'nominal_subwindow_x_min': {
                        'title': 'Large Megalisa Subwindow X Min',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'nominal_subwindow_x_max': {
                        'title': 'Large Megalisa Subwindow X Max',
                        'type': 'float',
                        'min': -1.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'nominal_subwindow_y_min': {
                        'title': 'Large Megalisa Subwindow Y Min',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': -1.0,
                    },
                    'nominal_subwindow_y_max': {
                        'title': 'Large Megalisa Subwindow Y Max',
                        'type': 'float',
                        'min': 0.0,
                        'max': 1.0,
                        'step': 0.001,
                        'factoryval': 1.0,
                    },
                    'enablediag': {
                        'title': 'Enable diagnostics',
                        'type': 'bool',
                        'factoryval': True,
                    },
                    'algorithm': {
                        'title': 'Auto-tune algorithm',
                        'type': 'list',
                        'values': {
                            'Analog': 0,
                            'Digital box sweep': 1,
                            'Digital line sweep': 2,
                            'Digital line sweep v2': 3,
                            'Box sizing': 4,
                        },
                        'factoryval': 3,
                    },
                    'algorithm_step1': {
                        'title': 'Centering Algorithm',
                        'type': 'list',
                        'values': {'No-Op': 0, 'Linesweep V2': 1, 'Physmodel': 3},
                        'factoryval': 3,
                    },
                    'algorithm_step2': {
                        'title': 'Box Sizing Algorithm',
                        'type': 'list',
                        'values': {'No-Op': 0, 'Modulecal Glint-based': 2},
                        'factoryval': 0,
                    },
                    'large_megalisa_xphase': {
                        'title': 'Large Megalisa X Phase',
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'large_megalisa_yphase': {
                        'title': 'Large Megalisa Y Phase',
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'nominal_x_min': {
                        'title': 'Nominal Autotune X Min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 0,
                    },
                    'nominal_x_max': {
                        'title': 'Nominal Autotune X Max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 1023,
                    },
                    'nominal_y_min': {
                        'title': 'Nominal Autotune Y Min',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 0,
                    },
                    'nominal_y_max': {
                        'title': 'Nominal Autotune Y Max',
                        'type': 'int',
                        'min': 0,
                        'max': 1023,
                        'step': 1,
                        'factoryval': 1023,
                    },
                },
            },
            'metrics': {
                'title': 'Per Tracker Metrics',
                'children': {
                    'lifetime_running_counter': {
                        'title': 'Running Lifetime Counter',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'uint',
                        'min': 0,
                        'step': 0.001,
                        'factoryval': 0,
                    }
                },
            },
            'operational': {
                'title': 'Operational',
                'children': {
                    'xphase': {
                        'title': 'X Phase',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                    'yphase': {
                        'title': 'Y Phase',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'min': 0,
                        'max': 360,
                        'step': 0.001,
                        'factoryval': 0,
                    },
                },
            },
            'eye_model': {
                'title': 'Model-based Eye Information',
                'children': {
                    'pos_x': {
                        'title': 'X Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                    'pos_y': {
                        'title': 'Y Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                    'pos_z': {
                        'title': 'Z Position',
                        'writable': ['HARDWARE', 'REMOTE_SERVER'],
                        'type': 'float',
                        'factoryval': 0,
                    },
                },
            },
            'deadtime_enable': {
                'title': 'Enable Dead Time',
                'type': 'bool',
                'factoryval': False,
                'related': ['deadtimemode'],
            },
            'component_offset_x': {
                'title': 'Component Offset X (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'component_offset_y': {
                'title': 'Component Offset Y (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'component_offset_z': {
                'title': 'Component Offset Z (mm)',
                'type': 'float',
                'factoryval': 0,
            },
            'subwindowing_enable': {
                'title': 'Sub Windowing Enable',
                'type': 'bool',
                'factoryval': False,
            },
            'subwindowing_x_min': {
                'title': 'Sub Windowing X Min',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_y_min': {
                'title': 'Sub Windowing Y Min',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_x_max': {
                'title': 'Sub Windowing X Max',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
            'subwindowing_y_max': {
                'title': 'Sub Windowing Y Max',
                'type': 'float',
                'factoryval': 0,
                'min': -1,
                'max': 1,
            },
        },
    },
    'blob': {
        'title': 'Blob Configuration',
        'children': {
            'spec': {
                'title': 'Spec Blob Configuration',
                'children': {
                    'rev': {
                        'children': {
                            'autotune': {
                                'title': 'Autotune Offsets Revision',
                                'type': 'int',
                                'factoryval': 0,
                                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                            },
                            'dynamic_fusion': {
                                'title': 'Dynamic Fusion Revision',
                                'type': 'int',
                                'factoryval': 0,
                                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                            },
                            'model_et': {
                                'title': 'Model ET Blob Revision',
                                'type': 'int',
                                'factoryval': 0,
                                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                            },
                            'model_priors': {
                                'title': 'Model Priors Blob Revision',
                                'type': 'int',
                                'factoryval': 0,
                                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                            },
                            'geometry': {
                                'title': 'Geometry Blob Revision',
                                'type': 'int',
                                'factoryval': 0,
                                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                            },
                        }
                    }
                },
            },
            'tuning': {
                'title': 'Tuning Blob Configuration',
                'children': {
                    'multiglint': {'title': 'Multiglint Blob', 'type': 'blob'},
                    'module_cal': {'title': 'Modulecal Blob', 'type': 'blob'},
                    'autotune_multiglint': {
                        'title': 'Autotune Multiglint Blob',
                        'type': 'blob',
                    },
                },
            },
            'user': {
                'title': 'User Blob Configuration',
                'children': {
                    'calibration': {'title': 'Calibration Blob', 'type': 'blob'}
                },
            },
        },
    },
    'general': {
        'title': 'General',
        'children': {
            'apiversion': {
                'title': 'API Version',
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'str',
                'factoryval': '',
                'max_length': 32,
            },
            'firmwareversion': {
                'title': 'Firmware Version',
                'writeable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'str',
                'factoryval': '',
                'max_length': 32,
            },
            'numtrackers': {
                'title': 'Number of trackers',
                'writeable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'int',
                'factoryval': 2,
            },
            'activeeyes': {
                'title': 'Active Eyes',
                'writeable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'list',
                'factoryval': [0, 1],
            },
        },
    },
    'metrics': {
        'title': 'Metrics',
        'children': {
            'flash_erase_count': {
                'title': 'Flash Erase Count',
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'uint',
                'min': 0,
                'step': 1,
                'factoryval': 0,
            },
            'flash_write_count': {
                'title': 'Flash Write Count',
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'uint',
                'min': 0,
                'step': 1,
                'factoryval': 0,
            },
            'lifetime_counter': {
                'title': 'Lifetime Counter (ms)',
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'uint',
                'min': 0,
                'step': 0.001,
                'factoryval': 0,
            },
        },
    },
    'eyetracker': {
        'title': 'Eyetracker constants',
        'children': {
            'pupil_offset': {
                'title': 'Pupil offset (mm)',
                'type': 'float',
                'min': 8,
                'max': 15,
                'step': 0.1,
                'factoryval': 12,
            },
            'pccr_enable': {'title': 'Enable PCCR', 'type': 'bool', 'factoryval': True},
            'realtime_z_enable': {
                'title': 'Enable Realtime Z',
                'type': 'bool',
                'factoryval': True,
            },
        },
    },
    'spec': {
        'title': 'Device Personalization',
        'children': {
            'product_id': {
                'title': 'Kit Configuration',
                'writable': ['HARDWARE', 'REMOTE_SERVER', 'ADMIN'],
                'type': 'list',
                'limits': {
                    'Unknown': 0,
                    'EXPERIMENTAL': 1,
                    'AHSM': 2,
                    'CUOAP': 3,
                    'EVK3P1': 4,
                    'EVK3P2': 5,
                    'EVK3P4': 6,
                    'GARC5': 7,
                    'GTK': 8,
                    'AHSM2': 9,
                    'EVK3P5': 10,
                    'SWALLOW': 11,
                    'AHSM3A1': 12,
                    'AHSM3A2': 13,
                    'SPARROW': 14,
                    'EVK3P6': 15,
                    'EVK4P0': 16,
                    'GANNET': 17,
                    'SPARROWG3': 18,
                    'EVK3P6G3': 19,
                    'AHSM3J': 20,
                    'MFGBENCH': 21,
                    'MFGBENCHG3': 22,
                    'AHSM3A1MOCKUP': 23,
                    'AHSM3A2MOCKUP': 24,
                    'AHSM3K': 25,
                    'EVK5P0': 26,
                    'AHSM3KL': 27,
                    'ZAPATA': 28,
                    'HWBENCH': 29,
                    'HOBBY': 30,
                    'EVK4P1': 31,
                    'DARTER': 32,
                    'SR21A': 33,
                    'SR21B': 34,
                    'AMBON_SHIELD': 35,
                    'SWALLOW21': 36,
                    'SR21C': 37,
                    'FALCON21_V5': 38,
                    'ALBATROSS21': 39,
                    'FALCON21': 40,
                    'MINDLINK_2P5MM': 41,
                    'MFGBENCH_LONGEVITY': 42,
                    'MERLIN22': 43,
                    'FALCON21_3GPD': 44,
                    'DARTERFOLDED3P2': 46,
                    'FALCON2': 47,
                    'MERLIN2': 48,
                },
                'factoryval': 0,
            },
            'board_type': {
                'title': 'Board Type',
                'writable': ['HARDWARE', 'ADMIN', 'REMOTE_SERVER'],
                'type': 'list',
                'factoryval': 0,
                'enabled': False,
                'limits': {
                    'DevboardV1': 0,
                    'V3Dac': 1,
                    'V3Pwm': 2,
                    'V4Dac': 3,
                    'DevboardV2': 4,
                    'DigiBrd': 5,
                    'DevboardV3': 6,
                    'SPIAdapter': 7,
                    'ComBrd': 8,
                    'VibraniumComBrd': 9,
                    'HybridV1': 10,
                    'Vibranium': 11,
                    'STDevShield': 12,
                    'CopperHub': 13,
                    'CopperFacePlate': 14,
                    'SamsungHub': 15,
                    'CopperEyeTube': 16,
                    'SamsungV1': 17,
                    'EVK3': 18,
                    'EVK3Hub': 19,
                    'BinocularHybridV1': 20,
                    'BinocularHybridHubV1': 21,
                    'Copper427Hub': 22,
                    'EVK3_1': 23,
                    'SamsungV2': 24,
                    'FPGADevboardV1': 25,
                    'SPIAdapterV2': 26,
                    'PccrEyeTrackerV1': 27,
                    'PccrPupilV1': 28,
                    'PccrHubV1': 29,
                    'BinocularHybridV2': 30,
                    'BinocularHybridHubV2': 31,
                    'STM32SPIAdapter': 32,
                    'SingleMCUV1': 33,
                    'DevboardV4': 35,
                    'SingleMCU3PD': 36,
                    'STL5DevShieldV1': 37,
                    'AHSM3ET': 38,
                    'AHSM3SPIAdapter': 39,
                    'AHSM3_3PD': 40,
                    'DevboardV4_3PD': 41,
                    'L5_EVK_V1': 42,
                    'L5_EVK_V1_3PD': 43,
                    'DevboardV5': 44,
                    'ZAPATA_V1': 45,
                    'EVK4': 46,
                    'DevboardV5_ALC': 48,
                    'L5_EVK_SR21': 49,
                    'AMBON_SHIELD': 50,
                    'L5_EVK_SR21_IRIS': 51,
                    'DEVBOARDV6': 52,
                    'INT_V1': 53,
                    'INT_V1_IRIS': 54,
                    'MERLIN22': 55,
                    'LP_INT_V2': 56,
                    'EVK4_V2': 57,
                    'VirtualClient': 4294967295,
                },
            },
            'serial_num': {
                'title': 'Device Serial',
                'writable': ['HARDWARE', 'ADMIN', 'REMOTE_SERVER'],
                'type': 'str',
                'factoryval': '',
                'max_length': 32,
            },
            'shared_detector_capability': {
                'title': 'Shared Detector Capability',
                'writable': ['HARDWARE', 'REMOTE_SERVER'],
                'type': 'bool',
                'factoryval': False,
            },
            'device_tune_version': {
                'title': 'Device Tune Version',
                'writable': ['HARDWARE', 'ADMIN', 'REMOTE_SERVER'],
                'type': 'uint',
                'factoryval': 0,
            },
            'device_tune_date': {
                'title': 'Device Tune Date',
                'writable': ['HARDWARE', 'ADMIN', 'REMOTE_SERVER'],
                'type': 'uint',
                'factoryval': 0,
            },
        },
    },
}
